@@ -61,7 +61,10 @@ QT_BEGIN_NAMESPACE
     \value MiscellaneousDevice  A miscellaneous device.
     \value ComputerDevice       A computer device or PDA.
     \value PhoneDevice          A telephone device.
-    \value LANAccessDevice      A device that provides access to a local area network.
+    \value LANAccessDevice      A device that provides access to a local area network
+                                (deprecated since Qt 5.13 and replaced by
+                                \l QBluetoothDeviceInfo::NetworkDevice).
+    \value NetworkDevice        A device that provides access to a local area network (since Qt 5.13).
     \value AudioVideoDevice     A device capable of playback or capture of audio and/or video.
     \value PeripheralDevice     A peripheral device such as a keyboard, mouse, and so on.
     \value ImagingDevice        An imaging device such as a display, printer, scanner or camera.
@@ -279,7 +282,9 @@ QBluetoothDeviceInfoPrivate::QBluetoothDeviceInfoPrivate() :
     serviceClasses(QBluetoothDeviceInfo::NoService),
     majorDeviceClass(QBluetoothDeviceInfo::MiscellaneousDevice),
     minorDeviceClass(0),
+#if QT_DEPRECATED_SINCE(5, 13)
     serviceUuidsCompleteness(QBluetoothDeviceInfo::DataUnavailable),
+#endif
     deviceCoreConfiguration(QBluetoothDeviceInfo::UnknownCoreConfiguration)
 {
 }
@@ -319,7 +324,9 @@ QBluetoothDeviceInfo::QBluetoothDeviceInfo(const QBluetoothAddress &address, con
     d->majorDeviceClass = static_cast<MajorDeviceClass>((classOfDevice >> 8) & 0x1f);
     d->serviceClasses = static_cast<ServiceClasses>((classOfDevice >> 13) & 0x7ff);
 
+#if QT_DEPRECATED_SINCE(5, 13)
     d->serviceUuidsCompleteness = DataUnavailable;
+#endif
 
     d->valid = true;
     d->cached = false;
@@ -350,7 +357,9 @@ QBluetoothDeviceInfo::QBluetoothDeviceInfo(const QBluetoothUuid &uuid, const QSt
     d->majorDeviceClass = static_cast<MajorDeviceClass>((classOfDevice >> 8) & 0x1f);
     d->serviceClasses = static_cast<ServiceClasses>((classOfDevice >> 13) & 0x7ff);
 
+#if QT_DEPRECATED_SINCE(5, 13)
     d->serviceUuidsCompleteness = DataUnavailable;
+#endif
 
     d->valid = true;
     d->cached = false;
@@ -417,7 +426,9 @@ QBluetoothDeviceInfo &QBluetoothDeviceInfo::operator=(const QBluetoothDeviceInfo
     d->serviceClasses = other.d_func()->serviceClasses;
     d->valid = other.d_func()->valid;
     d->cached = other.d_func()->cached;
+#if QT_DEPRECATED_SINCE(5, 13)
     d->serviceUuidsCompleteness = other.d_func()->serviceUuidsCompleteness;
+#endif
     d->serviceUuids = other.d_func()->serviceUuids;
     d->manufacturerData = other.d_func()->manufacturerData;
     d->rssi = other.d_func()->rssi;
@@ -448,8 +459,10 @@ bool QBluetoothDeviceInfo::operator==(const QBluetoothDeviceInfo &other) const
         return false;
     if (d->address != other.d_func()->address)
         return false;
+#if QT_DEPRECATED_SINCE(5, 13)
     if (d->serviceUuidsCompleteness != other.d_func()->serviceUuidsCompleteness)
         return false;
+#endif
     if (d->serviceUuids.count() != other.d_func()->serviceUuids.count())
         return false;
     if (d->serviceUuids != other.d_func()->serviceUuids)
@@ -535,7 +548,10 @@ quint8 QBluetoothDeviceInfo::minorDeviceClass() const
     return d->minorDeviceClass;
 }
 
+#if QT_DEPRECATED_SINCE(5, 13)
 /*!
+    \deprecated
+
     Sets the list of service UUIDs to \a uuids and the completeness of the data to \a completeness.
 */
 void QBluetoothDeviceInfo::setServiceUuids(const QList<QBluetoothUuid> &uuids,
@@ -543,9 +559,37 @@ void QBluetoothDeviceInfo::setServiceUuids(const QList<QBluetoothUuid> &uuids,
 {
     Q_D(QBluetoothDeviceInfo);
 
-    d->serviceUuids = uuids;
+    d->serviceUuids = uuids.toVector();
     d->serviceUuidsCompleteness = completeness;
 }
+#endif
+
+/*!
+    Sets the list of service UUIDs to \a uuids.
+    \since 5.13
+ */
+void QBluetoothDeviceInfo::setServiceUuids(const QVector<QBluetoothUuid> &uuids)
+{
+    Q_D(QBluetoothDeviceInfo);
+    d->serviceUuids = uuids;
+}
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+/*!
+    Returns the list of service UUIDS supported by the device. Most commonly this
+    list of uuids represents custom uuids or a uuid value specified by
+    \l QBluetoothUuid::ServiceClassUuid.
+
+    \sa serviceUuids()
+    \since 6.0
+*/
+QVector<QBluetoothUuid> QBluetoothDeviceInfo::serviceUuids() const
+{
+    Q_D(const QBluetoothDeviceInfo);
+    return d->serviceUuids;
+}
+
+#elif QT_DEPRECATED_SINCE(5, 13)
 
 /*!
     Returns the list of service UUIDS supported by the device. If \a completeness is not 0 it will
@@ -562,10 +606,28 @@ QList<QBluetoothUuid> QBluetoothDeviceInfo::serviceUuids(DataCompleteness *compl
     if (completeness)
         *completeness = d->serviceUuidsCompleteness;
 
-    return d->serviceUuids;
+    return d->serviceUuids.toList();
 }
 
+#else
+
+/*
+    Returns the list of service UUIDS supported by the device. Most commonly this
+    list of uuids represents custom uuids or a uuid value specified by
+    \l QBluetoothUuid::ServiceClassUuid.
+*/
+QList<QBluetoothUuid> QBluetoothDeviceInfo::serviceUuids() const
+{
+    Q_D(const QBluetoothDeviceInfo);
+    return d->serviceUuids.toList();
+}
+
+#endif //QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+
+#if QT_DEPRECATED_SINCE(5, 13)
 /*!
+    \deprecated
+
     Returns the completeness of the service UUID list.  If DataComplete is returned,
     serviceUuids() returns the complete list of service UUIDs supported by the device, otherwise
     only the partial or empty list of service UUIDs. To get a list
@@ -576,7 +638,7 @@ QBluetoothDeviceInfo::DataCompleteness QBluetoothDeviceInfo::serviceUuidsComplet
     Q_D(const QBluetoothDeviceInfo);
     return d->serviceUuidsCompleteness;
 }
-
+#endif
 
 /*!
     Returns all manufacturer ids attached to this device information.
@@ -607,19 +669,25 @@ QVector<quint16> QBluetoothDeviceInfo::manufacturerIds() const
     The interpretation of the data octets is defined by the manufacturer
     specified by the company identifier.
 
+    \note The remote device may provide multiple data entries per manufacturerId.
+    This function only returns the first entry. If all entries are needed use
+    \l manufacturerData() which returns a multi hash.
+
     \sa manufacturerIds(), setManufacturerData()
     \since 5.12
  */
 QByteArray QBluetoothDeviceInfo::manufacturerData(quint16 manufacturerId) const
 {
-    // TODO Currently not implemented on WinRT
     Q_D(const QBluetoothDeviceInfo);
     return d->manufacturerData.value(manufacturerId);
 }
 
 /*!
     Sets the advertised manufacturer \a data for the given \a manufacturerId.
-    Returns true if it was inserted or changed, false if it was already known.
+    Returns \c true if it was inserted, \c false if it was already known.
+
+    Since Qt 5.14, different values for \a data and the same \a manufacturerId no longer
+    replace each other but are accumulated for the duration of a device scan.
 
     \sa manufacturerData
     \since 5.12
@@ -627,9 +695,13 @@ QByteArray QBluetoothDeviceInfo::manufacturerData(quint16 manufacturerId) const
 bool QBluetoothDeviceInfo::setManufacturerData(quint16 manufacturerId, const QByteArray &data)
 {
     Q_D(QBluetoothDeviceInfo);
-    const auto it = d->manufacturerData.find(manufacturerId);
-    if (it != d->manufacturerData.end() && *it == data)
-        return false;
+    auto it = d->manufacturerData.constFind(manufacturerId);
+    while (it != d->manufacturerData.cend() && it.key() == manufacturerId) {
+        if (*it == data)
+            return false;
+        it++;
+    }
+
     d->manufacturerData.insert(manufacturerId, data);
     return true;
 }
@@ -637,6 +709,11 @@ bool QBluetoothDeviceInfo::setManufacturerData(quint16 manufacturerId, const QBy
 /*!
     Returns the complete set of all manufacturer data.
 
+    Some devices may provide multiple manufacturer data entries per manufacturer ID.
+    An example might be a Bluetooth Low Energy device that sends a different manufacturer data via
+    advertisement packets and scan response packets respectively. Therefore the returned hash table
+    may have multiple entries per manufacturer ID or hash key.
+
     \sa setManufacturerData
     \since 5.12
 */
