@@ -61,7 +61,7 @@ QLowEnergyControllerPrivate::~QLowEnergyControllerPrivate()
 
 bool QLowEnergyControllerPrivate::isValidLocalAdapter()
 {
-#ifdef QT_WINRT_BLUETOOTH
+#if defined(QT_WINRT_BLUETOOTH) || defined(Q_OS_DARWIN)
     return true;
 #endif
     if (localAdapter.isNull())
@@ -106,6 +106,9 @@ void QLowEnergyControllerPrivate::setError(
     case QLowEnergyController::RemoteHostClosedError:
         errorString = QLowEnergyController::tr("Remote device closed the connection");
         break;
+    case QLowEnergyController::AuthorizationError:
+        errorString = QLowEnergyController::tr("Failed to authorize on the remote device");
+        break;
     case QLowEnergyController::NoError:
         return;
     default:
@@ -120,6 +123,7 @@ void QLowEnergyControllerPrivate::setError(
 void QLowEnergyControllerPrivate::setState(
         QLowEnergyController::ControllerState newState)
 {
+    qCDebug(QT_BT) << "QLowEnergyControllerPrivate setting state to" << newState;
     Q_Q(QLowEnergyController);
     if (state == newState)
         return;
